Learn R Programming

Visualize.CRAN.Downloads (version 1.0.3)

lastyear.date: function that returns the date from one year ago

Description

function that returns the date from one year ago

Usage

lastyear.date()

Arguments