time.units: function to identify units of times based on the number of days
Description
function to identify units of times based on the number of days
Usage
# S3 method for units
time(tot.days)
Value
a vector with the "time units" included in the total number of days
Arguments
- tot.days
number of days